@@ -397,7 +397,7 @@ testthat::test_that(
 testthat::test_that(
   desc = "dataframe",
   code = {
-    testthat::expect_is(
+    testthat::expect_s3_class(
       statsExpressions::expr_anova_parametric(
         data = mtcars,
         x = cyl,
