@@ -6,7 +6,7 @@ testthat::test_that(
     testthat::skip_if(getRversion() < "3.6")
     testthat::skip_on_cran()
 
-    if (utils::packageVersion("correlation") >= package_version("0.5.0")) {
+    if (utils::packageVersion("correlation") > package_version("0.4.0")) {
       # `statsExpressions` output
       set.seed(123)
       using_function <-
@@ -100,7 +100,7 @@ testthat::test_that(
     testthat::skip_if(getRversion() < "3.6")
     testthat::skip_on_cran()
 
-    if (utils::packageVersion("correlation") >= package_version("0.5.0")) {
+    if (utils::packageVersion("correlation") > package_version("0.4.0")) {
       # `statsExpressions` output
       set.seed(123)
       using_function <-
@@ -157,7 +157,7 @@ testthat::test_that(
     testthat::skip_if(getRversion() < "3.6")
     testthat::skip_on_cran()
 
-    if (utils::packageVersion("correlation") >= package_version("0.5.0")) {
+    if (utils::packageVersion("correlation") > package_version("0.4.0")) {
       # using function
       set.seed(123)
       using_function <-
@@ -184,7 +184,7 @@ testthat::test_that(
             " = ",
             "1.756e-06",
             ", ",
-            widehat(italic(rho))["pb"],
+            widehat(italic(rho))["% bend"],
             " = ",
             "-0.5894",
             ", CI"["50%"],
@@ -248,7 +248,7 @@ testthat::test_that(
 testthat::test_that(
   desc = "dataframe",
   code = {
-    testthat::expect_is(
+    testthat::expect_s3_class(
       statsExpressions::expr_corr_test(
         data = mtcars,
         x = mpg,
