@@ -19,8 +19,7 @@ testthat::test_that(
           effsize.type = "d",
           var.equal = TRUE,
           conf.level = .99,
-          k = 5,
-          messages = FALSE
+          k = 5
         )
       )
 
@@ -302,7 +301,7 @@ testthat::test_that(
 testthat::test_that(
   desc = "dataframe",
   code = {
-    testthat::expect_is(
+    testthat::expect_s3_class(
       statsExpressions::expr_t_parametric(
         data = dplyr::filter(movies_long, genre == "Action" | genre == "Drama"),
         x = "genre",
